This is an getter method for pretreatments in an S4 object, usually of class
mediation_data.
Usage
pretreatments(object)
Value
The output depends on the S4 class of the input object. If it is a
multimedia model object, it will return a character vector of the outcome
variable names. Otherwise it returns the outcome data.