Learn R Programming

multimedia (version 0.2.0)

treatments,mediation_data-method: Treatments in a Mediation Data Object

Description

This is an accessor function to the @treatments slot in a mediation data object. It returns the entire set of observed treatments, in contrast to treatments() applied to a multimedia object, which only returns the names of the treatment variables.

Usage

# S4 method for mediation_data
treatments(object)

Value

A data.frame whose rows are samples and columns different treatments.

Arguments

object

An object of class mediation_data.

Examples

Run this code
exper <- demo_joy() |>
    mediation_data("PHQ", "treatment", starts_with("ASV"))
treatments(exper)

Run the code above in your browser using DataLab