treatments,mediation_data-method: Treatments in a Mediation Data Object
Description
This is an accessor function to the @treatments slot in a mediation data
object. It returns the entire set of observed treatments, in contrast to
treatments() applied to a multimedia object, which only returns the names of
the treatment variables.
Usage
# S4 method for mediation_data
treatments(object)
Value
A data.frame whose rows are samples and columns different treatments.