treatments,multimedia-method: Names of Treatments in a Multimedia Object
Description
This is a helper that returns the names of the treatment variables in an
object of class multimedia. It parses the graph in the DAG specifying the
mediation analysis, and it returns all variables of node type treatment.
Usage
# S4 method for multimedia
treatments(object)
Value
m A vector of strings containing the names of all the treatments.